Luma.Core
=========
.. image:: https://travis-ci.org/rm-hull/luma.core.svg?branch=master
   :target: https://travis-ci.org/rm-hull/luma.core

.. image:: https://coveralls.io/repos/github/rm-hull/luma.core/badge.svg?branch=master
   :target: https://coveralls.io/github/rm-hull/luma.core?branch=master

.. image:: https://requires.io/github/rm-hull/luma.core/requirements.svg?branch=master
   :target: https://requires.io/github/rm-hull/luma.core/requirements/?branch=master

.. image:: https://img.shields.io/maintenance/yes/2018.svg?maxAge=2592000

.. image:: https://img.shields.io/pypi/pyversions/luma.core.svg
    :target: https://pypi.python.org/pypi/luma.core

.. image:: https://img.shields.io/pypi/v/luma.core.svg
   :target: https://pypi.python.org/pypi/luma.core

.. toctree::
   :maxdepth: 2

   intro
   install
   api-documentation

.. include:: ../CONTRIBUTING.rst
.. include:: ../CHANGES.rst
.. include:: ../LICENSE.rst

